==> jc-1.4.0.tar.gz: javax/swing/plaf/ComboBoxUI.h <==
// public abstract class javax.swing.plaf.ComboBoxUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b5646fddc98e0bec javax_swing_plaf_ComboBoxUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ComboBoxUI_H_
#define _JC_javax_swing_plaf_ComboBoxUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComboBox$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ComboBoxUI$sub_refs	_jc_javax_swing_plaf_ComboBoxUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs	_jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$refs	_jc_javax_swing_plaf_ComboBoxUI$refs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$nonrefs	_jc_javax_swing_plaf_ComboBoxUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$object	_jc_javax_swing_plaf_ComboBoxUI$object;

typedef const struct _jc_javax_swing_plaf_ComboBoxUI$vmethods	_jc_javax_swing_plaf_ComboBoxUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ComboBoxUI$vtable	_jc_javax_swing_plaf_ComboBoxUI$vtable;
typedef const struct _jc_javax_swing_plaf_ComboBoxUI$vtype	_jc_javax_swing_plaf_ComboBoxUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ComboBoxUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *);

// Virtual methods
extern jboolean _jc_javax_swing_plaf_ComboBoxUI$method$isFocusTraversable$cfcabf7b8a08c018(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *);
extern jboolean _jc_javax_swing_plaf_ComboBoxUI$method$isPopupVisible$a96db1934b9209b4(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *);
extern void _jc_javax_swing_plaf_ComboBoxUI$method$setPopupVisible$eeaef36526e9ad3a(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_ComboBoxUI$method_info$isFocusTraversable$cfcabf7b8a08c018;
extern _jc_method _jc_javax_swing_plaf_ComboBoxUI$method_info$isPopupVisible$a96db1934b9209b4;
extern _jc_method _jc_javax_swing_plaf_ComboBoxUI$method_info$setPopupVisible$eeaef36526e9ad3a;

// Virtual methods structure
struct _jc_javax_swing_plaf_ComboBoxUI$vmethods {
	jboolean	(*isFocusTraversable$cfcabf7b8a08c018)(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *);
	jboolean	(*isPopupVisible$a96db1934b9209b4)(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *);
	void	(*setPopupVisible$eeaef36526e9ad3a)(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *, jboolean);
};

// Vtable
struct _jc_javax_swing_plaf_ComboBoxUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ComboBoxUI$vmethods	javax_swing_plaf_ComboBoxUI;
};

// Vtype
struct _jc_javax_swing_plaf_ComboBoxUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ComboBoxUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComboBoxUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ComboBoxUI$refs {
    _jc_javax_swing_plaf_ComboBoxUI$sub_refs	javax_swing_plaf_ComboBoxUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ComboBoxUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs	javax_swing_plaf_ComboBoxUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ComboBoxUI$object {
	_jc_javax_swing_plaf_ComboBoxUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ComboBoxUI$vtype	*vtype;
	_jc_javax_swing_plaf_ComboBoxUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ComboBoxUI$vtype _jc_javax_swing_plaf_ComboBoxUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ComboBoxUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ComboBoxUI$class_object;

#endif	/* _JC_javax_swing_plaf_ComboBoxUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/ComboBoxUI.h <==
// public abstract class javax.swing.plaf.ComboBoxUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b5646fddc98e0bec javax_swing_plaf_ComboBoxUI
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ComboBoxUI_H_
#define _JC_javax_swing_plaf_ComboBoxUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComboBox$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ComboBoxUI$sub_refs	_jc_javax_swing_plaf_ComboBoxUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs	_jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$refs	_jc_javax_swing_plaf_ComboBoxUI$refs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$nonrefs	_jc_javax_swing_plaf_ComboBoxUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ComboBoxUI$object	_jc_javax_swing_plaf_ComboBoxUI$object;

typedef const struct _jc_javax_swing_plaf_ComboBoxUI$vmethods	_jc_javax_swing_plaf_ComboBoxUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ComboBoxUI$vtable	_jc_javax_swing_plaf_ComboBoxUI$vtable;
typedef const struct _jc_javax_swing_plaf_ComboBoxUI$vtype	_jc_javax_swing_plaf_ComboBoxUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ComboBoxUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_plaf_ComboBoxUI$method$isFocusTraversable$cfcabf7b8a08c018(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_plaf_ComboBoxUI$method$isPopupVisible$a96db1934b9209b4(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_ComboBoxUI$method$setPopupVisible$eeaef36526e9ad3a(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_ComboBoxUI$method_info$isFocusTraversable$cfcabf7b8a08c018;
extern _jc_method _jc_javax_swing_plaf_ComboBoxUI$method_info$isPopupVisible$a96db1934b9209b4;
extern _jc_method _jc_javax_swing_plaf_ComboBoxUI$method_info$setPopupVisible$eeaef36526e9ad3a;

// Virtual methods structure
struct _jc_javax_swing_plaf_ComboBoxUI$vmethods {
	jboolean	(*isFocusTraversable$cfcabf7b8a08c018)(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *) _JC_JCNI_ATTR;
	jboolean	(*isPopupVisible$a96db1934b9209b4)(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *) _JC_JCNI_ATTR;
	void	(*setPopupVisible$eeaef36526e9ad3a)(_jc_env *, struct _jc_javax_swing_plaf_ComboBoxUI$object *, struct _jc_javax_swing_JComboBox$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_ComboBoxUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ComboBoxUI$vmethods	javax_swing_plaf_ComboBoxUI;
};

// Vtype
struct _jc_javax_swing_plaf_ComboBoxUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ComboBoxUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComboBoxUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ComboBoxUI$refs {
    _jc_javax_swing_plaf_ComboBoxUI$sub_refs	javax_swing_plaf_ComboBoxUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ComboBoxUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ComboBoxUI$sub_nonrefs	javax_swing_plaf_ComboBoxUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ComboBoxUI$object {
	_jc_javax_swing_plaf_ComboBoxUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ComboBoxUI$vtype	*vtype;
	_jc_javax_swing_plaf_ComboBoxUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ComboBoxUI$vtype _jc_javax_swing_plaf_ComboBoxUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ComboBoxUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ComboBoxUI$class_object;

#endif	/* _JC_javax_swing_plaf_ComboBoxUI_H_ */
